@@ -17,22 +17,22 @@ class StringReaderTest extends TestCase
     public function testReadFails(): void
     {
         $tempFile = (string) tempnam(sys_get_temp_dir(), 'phpMyAdmin_StringReaderTest');
-        $this->assertFileExists($tempFile);
+        self::assertFileExists($tempFile);
         $stringReader = new StringReader($tempFile);
         unlink($tempFile);
         $actual = $stringReader->read(-1, -1);
-        $this->assertSame('', $actual);
+        self::assertSame('', $actual);
     }
 
     public function testReadIntArray(): void
     {
         $tempFile = (string) tempnam(sys_get_temp_dir(), 'phpMyAdmin_StringReaderTest');
         file_put_contents($tempFile, "\0\0\0\0\0\0\0\0\0\0\0\0");
-        $this->assertFileExists($tempFile);
+        self::assertFileExists($tempFile);
         $stringReader = new StringReader($tempFile);
         unlink($tempFile);
         $actual = $stringReader->readintarray('V', 2, 2);
-        $this->assertSame([
+        self::assertSame([
             1 => 0,
             2 => 0,
         ], $actual);
